# Generated by Django 2.2 on 2019-04-29 14:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0003_auto_20190429_1422'),
    ]

    operations = [
        migrations.AlterField(
            model_name='candidate',
            name='slug',
            field=models.SlugField(default='', unique=True),
            preserve_default=False,
        ),
    ]
