# Generated by Django 2.2.1 on 2019-05-01 18:52

from django.db import migrations, models
import issuestracker.utils.storage_service


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0008_remove_candidate_headshot'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='social_description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='category',
            name='social_image',
            field=models.ImageField(blank=True, null=True, storage=issuestracker.utils.storage_service.StorageService(), upload_to='%Y/%m/'),
        ),
        migrations.AddField(
            model_name='category',
            name='social_title',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='issue',
            name='social_description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='issue',
            name='social_image',
            field=models.ImageField(blank=True, null=True, storage=issuestracker.utils.storage_service.StorageService(), upload_to='%Y/%m/'),
        ),
        migrations.AddField(
            model_name='issue',
            name='social_title',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
