# Generated by Django 2.2 on 2019-04-29 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0002_auto_20190424_1640'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='issue',
            options={'ordering': ['name']},
        ),
        migrations.AddField(
            model_name='candidate',
            name='slug',
            field=models.SlugField(blank=True, null=True),
        ),
    ]
