# Generated by Django 2.2 on 2019-04-24 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='last_published',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='category',
            name='last_updated',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='issue',
            name='last_published',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='issue',
            name='last_updated',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
